========
Features
========

Machines
--------

* A :py:class:`.automaton.machines.FiniteMachine` state machine.
* A :py:class:`.automaton.machines.HierarchicalFiniteMachine` hierarchical
  state machine.

Runners
-------

* A :py:class:`.automaton.runners.FiniteRunner` state machine runner.
* A :py:class:`.automaton.runners.HierarchicalRunner` hierarchical state
  machine runner.
